@@ -18,7 +18,6 @@ import logging
 
 from osc_lib.command import command
 from osc_lib import exceptions as osc_exc
-import six
 
 from designateclient import utils
 from designateclient.v2.cli import common
@@ -55,7 +54,10 @@ class ListZonesCommand(command.Lister):
 
         parser.add_argument('--name', help="Zone Name", required=False)
         parser.add_argument('--email', help="Zone Email", required=False)
-        parser.add_argument('--type', help="Zone Type", required=False)
+        parser.add_argument('--type', help="Zone Type",
+                            choices=["PRIMARY", "SECONDARY"],
+                            default="PRIMARY",
+                            required=False)
         parser.add_argument('--ttl', help="Time To Live (Seconds)",
                             required=False)
         parser.add_argument('--description', help="Description",
@@ -91,7 +93,7 @@ class ListZonesCommand(command.Lister):
 
         data = get_all(client.zones.list, criterion)
 
-        cols = self.columns
+        cols = list(self.columns)
 
         if client.session.all_projects:
             cols.insert(1, 'project_id')
@@ -118,7 +120,7 @@ class ShowZoneCommand(command.ShowOne):
         data = client.zones.get(parsed_args.id)
 
         _format_zone(data)
-        return six.moves.zip(*sorted(six.iteritems(data)))
+        return zip(*sorted(data.items()))
 
 
 class CreateZoneCommand(command.ShowOne):
@@ -129,7 +131,9 @@ class CreateZoneCommand(command.ShowOne):
 
         parser.add_argument('name', help="Zone Name")
         parser.add_argument('--email', help="Zone Email")
-        parser.add_argument('--type', help="Zone Type", default='PRIMARY')
+        parser.add_argument('--type', help="Zone Type",
+                            choices=["PRIMARY", "SECONDARY"],
+                            default='PRIMARY')
         parser.add_argument('--ttl', type=int, help="Time To Live (Seconds)")
         parser.add_argument('--description', help="Description")
         parser.add_argument('--masters', help="Zone Masters", nargs='+')
@@ -181,7 +185,7 @@ class CreateZoneCommand(command.ShowOne):
             parsed_args.name, parsed_args.type, **payload)
 
         _format_zone(data)
-        return six.moves.zip(*sorted(six.iteritems(data)))
+        return zip(*sorted(data.items()))
 
 
 class SetZoneCommand(command.ShowOne):
@@ -226,7 +230,7 @@ class SetZoneCommand(command.ShowOne):
 
         updated = client.zones.update(parsed_args.id, data)
         _format_zone(updated)
-        return six.moves.zip(*sorted(six.iteritems(updated)))
+        return zip(*sorted(updated.items()))
 
 
 class DeleteZoneCommand(command.ShowOne):
@@ -249,7 +253,7 @@ class DeleteZoneCommand(command.ShowOne):
         LOG.info('Zone %s was deleted', parsed_args.id)
 
         _format_zone(data)
-        return six.moves.zip(*sorted(six.iteritems(data)))
+        return zip(*sorted(data.items()))
 
 
 class AbandonZoneCommand(command.Command):
@@ -318,7 +322,7 @@ class CreateTransferRequestCommand(command.ShowOne):
         data = client.zone_transfers.create_request(
             parsed_args.zone_id, parsed_args.target_project_id,
             parsed_args.description)
-        return six.moves.zip(*sorted(six.iteritems(data)))
+        return zip(*sorted(data.items()))
 
 
 class ListTransferRequestsCommand(command.Lister):
@@ -363,7 +367,7 @@ class ShowTransferRequestCommand(command.ShowOne):
 
         data = client.zone_transfers.get_request(parsed_args.id)
 
-        return six.moves.zip(*sorted(six.iteritems(data)))
+        return zip(*sorted(data.items()))
 
 
 class SetTransferRequestCommand(command.ShowOne):
@@ -393,7 +397,7 @@ class SetTransferRequestCommand(command.ShowOne):
             data['description'] = parsed_args.description
 
         updated = client.zone_transfers.update_request(parsed_args.id, data)
-        return six.moves.zip(*sorted(six.iteritems(updated)))
+        return zip(*sorted(updated.items()))
 
 
 class DeleteTransferRequestCommand(command.Command):
@@ -439,7 +443,7 @@ class AcceptTransferRequestCommand(command.ShowOne):
 
         data = client.zone_transfers.accept_request(
             parsed_args.transfer_id, parsed_args.key)
-        return six.moves.zip(*sorted(six.iteritems(data)))
+        return zip(*sorted(data.items()))
 
 
 class ListTransferAcceptsCommand(command.Lister):
@@ -460,7 +464,7 @@ class ListTransferAcceptsCommand(command.Lister):
         client = self.app.client_manager.dns
         common.set_all_common_headers(client, parsed_args)
 
-        data = client.zone_transfers.list_requests()
+        data = client.zone_transfers.list_accepts()
 
         cols = self.columns
         return cols, (utils.get_item_properties(s, cols) for s in data)
@@ -484,7 +488,7 @@ class ShowTransferAcceptCommand(command.ShowOne):
 
         data = client.zone_transfers.get_accept(parsed_args.id)
 
-        return six.moves.zip(*sorted(six.iteritems(data)))
+        return zip(*sorted(data.items()))
 
 
 class ExportZoneCommand(command.ShowOne):
@@ -509,7 +513,7 @@ class ExportZoneCommand(command.ShowOne):
 
         LOG.info('Zone Export %s was created', data['id'])
 
-        return six.moves.zip(*sorted(six.iteritems(data)))
+        return zip(*sorted(data.items()))
 
 
 class ListZoneExportsCommand(command.Lister):
@@ -562,7 +566,7 @@ class ShowZoneExportCommand(command.ShowOne):
             parsed_args.zone_export_id)
         _format_zone_export_record(data)
 
-        return six.moves.zip(*sorted(six.iteritems(data)))
+        return zip(*sorted(data.items()))
 
 
 class DeleteZoneExportCommand(command.Command):
@@ -635,7 +639,7 @@ class ImportZoneCommand(command.ShowOne):
 
         LOG.info('Zone Import %s was created', data['id'])
 
-        return six.moves.zip(*sorted(six.iteritems(data)))
+        return zip(*sorted(data.items()))
 
 
 class ListZoneImportsCommand(command.Lister):
@@ -689,7 +693,7 @@ class ShowZoneImportCommand(command.ShowOne):
             parsed_args.zone_import_id)
         _format_zone_import_record(data)
 
-        return six.moves.zip(*sorted(six.iteritems(data)))
+        return zip(*sorted(data.items()))
 
 
 class DeleteZoneImportCommand(command.Command):
