@@ -1,9 +1,8 @@
 import logging
+import os
 import uuid
 
 from designateclient.v2 import client
-from designateclient import shell
-from designateclient import utils
 
 from keystoneauth1.identity import generic
 from keystoneauth1 import session as keystone_session
@@ -12,10 +11,10 @@ from keystoneauth1 import session as keystone_session
 logging.basicConfig(level='DEBUG')
 
 auth = generic.Password(
-    auth_url=shell.env('OS_AUTH_URL'),
-    username=shell.env('OS_USERNAME'),
-    password=shell.env('OS_PASSWORD'),
-    project_name=shell.env('OS_PROJECT_NAME'),
+    auth_url=os.environ.get('OS_AUTH_URL'),
+    username=os.environ.get('OS_USERNAME'),
+    password=os.environ.get('OS_PASSWORD'),
+    project_name=os.environ.get('OS_PROJECT_NAME'),
     project_domain_id='default',
     user_domain_id='default')
 
